import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
SCRIPTS_DIR = os.path.join(BASE_DIR, "ppieces/scripts")
TEMPLATES_DIR = os.path.join(BASE_DIR, "ppieces/templates")
